# Coauthor AI Agent

```{include} ../README.md
:start-after: <!-- start mini-description -->
:end-before: <!-- end mini-description -->
```

```{toctree}
---
caption: For users
hidden: true
---
users/installation_and_usage.md
users/configuration_file.md
contributors/contributing.md
users/changelog.md
```

<!--
```{toctree}
---
caption: For contributors
hidden: true
---
contributors/contributing.md
```
-->

```{toctree}
---
caption: External links
hidden: true
---
GitLab repository <https://gitlab.com/c2platform/c2/coauthor>
PyPI page <https://pypi.org/project/coauthor/>
```
